You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@atlas.apache.org by sa...@apache.org on 2020/05/07 15:49:45 UTC

[atlas] branch branch-2.0 updated: ATLAS-3764 : Set default value for atlas.graph.index.search.max-result-set-size in Atlas ApplicationProperties #2

This is an automated email from the ASF dual-hosted git repository.

sarath pushed a commit to branch branch-2.0
in repository https://gitbox.apache.org/repos/asf/atlas.git


The following commit(s) were added to refs/heads/branch-2.0 by this push:
     new 4addecb  ATLAS-3764 : Set default value for atlas.graph.index.search.max-result-set-size in Atlas ApplicationProperties #2
4addecb is described below

commit 4addecbea6294f0dc95ebb26ac8e3d17449ecbb8
Author: nixonrodrigues <ni...@apache.org>
AuthorDate: Tue May 5 22:23:51 2020 +0530

    ATLAS-3764 : Set default value for atlas.graph.index.search.max-result-set-size in Atlas ApplicationProperties #2
    
    Change-Id: Ied094f9dfb701de9bd93de109f94df17c6e94a8c
    (cherry picked from commit b7b7c840c033d7d2553e804d0388e63d9cbc8e0f)
---
 intg/src/main/java/org/apache/atlas/ApplicationProperties.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/intg/src/main/java/org/apache/atlas/ApplicationProperties.java b/intg/src/main/java/org/apache/atlas/ApplicationProperties.java
index c419233..3ba5061 100644
--- a/intg/src/main/java/org/apache/atlas/ApplicationProperties.java
+++ b/intg/src/main/java/org/apache/atlas/ApplicationProperties.java
@@ -355,8 +355,8 @@ public final class ApplicationProperties extends PropertiesConfiguration {
             }
         }
 
-        // setting value for 'atlas.graph.index.search.max-result-set-size' (default = 2147483647)
-        int indexMaxResultSetSize = getInt(INDEX_SEARCH_MAX_RESULT_SET_SIZE, Integer.MAX_VALUE);
+        // setting value for 'atlas.graph.index.search.max-result-set-size' (default = 500000)
+        int indexMaxResultSetSize = getInt(INDEX_SEARCH_MAX_RESULT_SET_SIZE, 500000);
 
         clearPropertyDirect(INDEX_SEARCH_MAX_RESULT_SET_SIZE);
         addPropertyDirect(INDEX_SEARCH_MAX_RESULT_SET_SIZE, indexMaxResultSetSize);